@@ -285,16 +285,24 @@ amcheck <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
     prior.cols <- priors[,2] %in% c(1:ncol(x))
     prior.rows <- priors[,1] %in% c(0:nrow(x))
 
-                                        # Error code: 9
-                                        # priors set for cells that aren't in the data
+    ## Error code: 9
+    ## priors set for cells that aren't in the data
     if (sum(c(!prior.cols,!prior.rows)) != 0) {
       error.code <- 9
       error.mess <- "There are priors set on cells that don't exist."
       return(list(code=error.code,mess=error.mess))
     }
 
-                                        # Error code: 12
-                                        # confidences have to be in 0-1
+    ## Error code: 59
+    ## no priors on nominal variables
+    if (any(priors[,2] %in% noms)) {
+      error.code <- 59
+      error.mess <- "Cannot set priors on nominal variables. "
+      return(list(code = error.code, mess = error.mess))
+    }
+
+    ## Error code: 12
+    ## confidences have to be in 0-1
     if (ncol(priors) == 5) {
       if (any(priors[,5] <= 0) || any(priors[,5] >= 1)) {
         error.code<-12
@@ -373,8 +381,8 @@ amcheck <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
   }
 
 
-                                        #Error code: 14
-                                        #ts canonot equal cs
+  ## Error code: 14
+  ## ts canonot equal cs
   if (!identical(ts,NULL) && !identical(cs,NULL)) {
     if (ts==cs) {
       error.code<-14
@@ -522,6 +530,12 @@ amcheck <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
                         "interaction between polynomial of time and the cross-section.")
       return(list(code=error.code,mess=error.mess))
     }
+    if (sum(is.na(x[,cs])) > 0) {
+      error.code <- 60
+      error.mess <-
+        paste("There are missing values in the 'cs' variable.")
+      return(list(code=error.code,mess=error.mess))
+    }
 
   }
 
@@ -711,6 +725,17 @@ amcheck <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
     error.mess<-paste("There is only 1 column of data. Cannot impute.")
     return(list(code=error.code,mess=error.mess))
   }
+  ts.nulls <- is.null(polytime) & is.null(splinetime)
+  ts.zeros <- (polytime == 0) & (splinetime == 0)
+  if (!isTRUE(polytime > 0) & !isTRUE(splinetime > 0)) {
+    if (!isTRUE(intercs) & !is.null(ts)) {
+      if (ncol(x[,-c(ts,cs,idvars), drop = FALSE]) == 1) {
+        error.code<-61
+        error.mess<-paste("There is only 1 column of data after removing the ts, cs and idvars. Cannot impute without adding polytime.")
+        return(list(code=error.code,mess=error.mess))
+      }
+    }
+  }
 
 
                                         #Error code: 43
